==> realtime_trains_py-2025.2.0b2.tar.gz: realtime_trains_py-2025.2.0b2/examples/adv_pre_example.py <==
from realtime_trains_py import RealtimeTrainsPy

# Initialise RealtimeTrainsPy
rtt = RealtimeTrainsPy(
    username="YOUR_USERNAME", # <----- CHANGE ME
    password="YOUR_PASSWORD", # <----- CHANGE ME
    complexity="a.p"
)

#### EXAMPLE 1 ####

# Query for getting the next 5 arrivals at Norwich
rtt.get_arrivals(tiploc="NRCH", rows=5)

### EXAMPLE OUTPUT ###
# Arrivals board for Norwich. Generated at xx:xx:xx on 10/01/25.
# ╭──────────────────┬───────────────┬─────────────────────────┬────────────┬──────────────────┬───────────────╮
# │ Booked Arrival   │ Destination   │ Origin                  │   Platform │ Actual Arrival   │ Service UID   │
# ├──────────────────┼───────────────┼─────────────────────────┼────────────┼──────────────────┼───────────────┤
# │ 22:09            │ Norwich       │ Sheringham              │          6 │ On time          │ G29355        │
# ├──────────────────┼───────────────┼─────────────────────────┼────────────┼──────────────────┼───────────────┤
# │ 22:18            │ Norwich       │ London Liverpool Street │          2 │ Exp 22:17        │ G27476        │
# ├──────────────────┼───────────────┼─────────────────────────┼────────────┼──────────────────┼───────────────┤
# │ 22:32            │ Norwich       │ Lowestoft               │          5 │ Exp 22:31        │ G28577        │
# ├──────────────────┼───────────────┼─────────────────────────┼────────────┼──────────────────┼───────────────┤
# │ 22:35            │ Norwich       │ Cambridge               │          4 │ Exp 22:34        │ G27199        │
# ├──────────────────┼───────────────┼─────────────────────────┼────────────┼──────────────────┼───────────────┤
# │ 22:50            │ Norwich       │ Great Yarmouth          │          6 │ Exp 22:48        │ G29128        │
# ╰──────────────────┴───────────────┴─────────────────────────┴────────────┴──────────────────┴───────────────╯



#### EXAMPLE 2 ####

# Query for getting the next 10 departures from Hull around 10:00 UTC on 10th January 2025
rtt.get_departures(tiploc="HULL", date="2025/01/10", time="1000", rows=10)

### EXAMPLE OUTPUT ###
# Departure board for Hull. Generated at xx:xx:xx on 10/01/25.
# ╭────────────────────┬───────────────────────┬────────────┬────────────────────┬───────────────╮
# │ Booked Departure   │ Destination           │   Platform │ Actual Departure   │ Service UID   │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 09:47              │ York                  │          3 │ On time            │ G31323        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 09:50              │ Doncaster             │          1 │ On time            │ W47587        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 09:59              │ Bridlington           │          4 │ On time            │ W50814        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:03              │ Liverpool Lime Street │          5 │ On time            │ P12814        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:15              │ Halifax               │          1 │ On time            │ W48977        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:21              │ Scarborough           │          4 │ On time            │ W46501        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:23              │ Sheffield             │          3 │ On time            │ W46193        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:34              │ London Kings Cross    │          7 │ On time            │ N35979        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:47              │ York                  │          3 │ On time            │ W49960        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:50              │ Doncaster             │          1 │ On time            │ W47603        │
# ╰────────────────────┴───────────────────────┴────────────┴────────────────────┴───────────────╯



#### EXAMPLE 3 ####

# Query for getting the details of the service with service_uid "W47587" 
rtt.get_service("W47587")

### EXAMPLE OUTPUT ###
# # 2C56 (W47587) 
#   09:50 Hull to Doncaster
#   Pathed as DMU: train class S
#   Operated by Northern

#   Generated at xx:xx:xx on 10/01/25.
# ╭───────────────────────┬──────────────────┬──────────────────┬────────────┬────────┬────────────────────┬────────────────────╮
# │ Stop Name             │ Booked Arrival   │ Actual Arrival   │   Platform │ Line   │ Booked Departure   │ Actual Departure   │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Hull                  │                  │                  │          1 │ -      │ 09:50              │ 09:50              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Hessle                │ 09:57            │ 09:56            │          1 │ -      │ 09:57              │ 09:57              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Ferriby               │ 10:02            │ 10:01            │          2 │ -      │ 10:02              │ 10:02              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Brough                │ 10:06            │ 10:07            │          2 │ -      │ 10:07              │ 10:08              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Gilberdyke            │ 10:14            │ 10:15            │          2 │ USM    │ 10:14              │ 10:16              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Goole                 │ 10:23            │ 10:23            │          2 │ -      │ 10:24              │ 10:25              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Thorne North          │ 10:33            │ 10:33            │          1 │ -      │ 10:33              │ 10:35              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Hatfield & Stainforth │ 10:39            │ 10:39            │          1 │ DSF    │ 10:40              │ 10:40              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Kirk Sandall          │ 10:44            │ 10:44            │          1 │ -      │ 10:44              │ 10:45              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Doncaster             │ 10:53            │ 10:52            │          1 │ -      │                    │                    │
# ╰───────────────────────┴──────────────────┴──────────────────┴────────────┴────────┴────────────────────┴────────────────────╯

==> realtime_trains_py-2025.3.2.tar.gz: realtime_trains_py-2025.3.2/examples/adv_pre_example.py <==
from realtime_trains_py import RealtimeTrainsPy

# Initialise RealtimeTrainsPy
rtt = RealtimeTrainsPy(
    username="YOUR_USERNAME", # <----- CHANGE ME
    password="YOUR_PASSWORD", # <----- CHANGE ME
    complexity="a.p"
)

#### EXAMPLE 1 ####

# Query for getting the next 5 arrivals at Norwich
rtt.get_arrivals(tiploc="NRCH", rows=5)

### EXAMPLE OUTPUT ###
# Arrivals board for Norwich. Generated at xx:xx:xx on xx/xx/xx.
# ╭──────────────────┬───────────────┬─────────────────────────┬────────────┬──────────────────┬───────────────╮
# │ Booked Arrival   │ Destination   │ Origin                  │   Platform │ Actual Arrival   │ Service UID   │
# ├──────────────────┼───────────────┼─────────────────────────┼────────────┼──────────────────┼───────────────┤
# │ 22:09            │ Norwich       │ Sheringham              │          6 │ On time          │ G29355        │
# ├──────────────────┼───────────────┼─────────────────────────┼────────────┼──────────────────┼───────────────┤
# │ 22:18            │ Norwich       │ London Liverpool Street │          2 │ Exp 22:17        │ G27476        │
# ├──────────────────┼───────────────┼─────────────────────────┼────────────┼──────────────────┼───────────────┤
# │ 22:32            │ Norwich       │ Lowestoft               │          5 │ Exp 22:31        │ G28577        │
# ├──────────────────┼───────────────┼─────────────────────────┼────────────┼──────────────────┼───────────────┤
# │ 22:35            │ Norwich       │ Cambridge               │          4 │ Exp 22:34        │ G27199        │
# ├──────────────────┼───────────────┼─────────────────────────┼────────────┼──────────────────┼───────────────┤
# │ 22:50            │ Norwich       │ Great Yarmouth          │          6 │ Exp 22:48        │ G29128        │
# ╰──────────────────┴───────────────┴─────────────────────────┴────────────┴──────────────────┴───────────────╯



#### EXAMPLE 2 ####

# Query for getting the next 10 departures from Hull around 10:00 UTC on 10th January 2025
rtt.get_departures(tiploc="HULL", date="2025/01/10", time="1000", rows=10)

### EXAMPLE OUTPUT ###
# Departure board for Hull. Generated at xx:xx:xx on xx/xx/xx.
# ╭────────────────────┬───────────────────────┬────────────┬────────────────────┬───────────────╮
# │ Booked Departure   │ Destination           │   Platform │ Actual Departure   │ Service UID   │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 09:47              │ York                  │          3 │ On time            │ G31323        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 09:50              │ Doncaster             │          1 │ On time            │ W47587        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 09:59              │ Bridlington           │          4 │ On time            │ W50814        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:03              │ Liverpool Lime Street │          5 │ On time            │ P12814        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:15              │ Halifax               │          1 │ On time            │ W48977        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:21              │ Scarborough           │          4 │ On time            │ W46501        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:23              │ Sheffield             │          3 │ On time            │ W46193        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:34              │ London Kings Cross    │          7 │ On time            │ N35979        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:47              │ York                  │          3 │ On time            │ W49960        │
# ├────────────────────┼───────────────────────┼────────────┼────────────────────┼───────────────┤
# │ 10:50              │ Doncaster             │          1 │ On time            │ W47603        │
# ╰────────────────────┴───────────────────────┴────────────┴────────────────────┴───────────────╯



#### EXAMPLE 3 ####

# Query for getting the details of the service with service_uid "W47587" 
rtt.get_service("W47587")

### EXAMPLE OUTPUT ###
# # 2C56 (W47587) 
#   09:50 Hull to Doncaster
#   Pathed as DMU: train class S
#   Operated by Northern

#   Generated at xx:xx:xx on xx/xx/xx.
# ╭───────────────────────┬──────────────────┬──────────────────┬────────────┬────────┬────────────────────┬────────────────────╮
# │ Stop Name             │ Booked Arrival   │ Actual Arrival   │   Platform │ Line   │ Booked Departure   │ Actual Departure   │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Hull                  │                  │                  │          1 │ -      │ 09:50              │ 09:50              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Hessle                │ 09:57            │ 09:56            │          1 │ -      │ 09:57              │ 09:57              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Ferriby               │ 10:02            │ 10:01            │          2 │ -      │ 10:02              │ 10:02              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Brough                │ 10:06            │ 10:07            │          2 │ -      │ 10:07              │ 10:08              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Gilberdyke            │ 10:14            │ 10:15            │          2 │ USM    │ 10:14              │ 10:16              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Goole                 │ 10:23            │ 10:23            │          2 │ -      │ 10:24              │ 10:25              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Thorne North          │ 10:33            │ 10:33            │          1 │ -      │ 10:33              │ 10:35              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Hatfield & Stainforth │ 10:39            │ 10:39            │          1 │ DSF    │ 10:40              │ 10:40              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Kirk Sandall          │ 10:44            │ 10:44            │          1 │ -      │ 10:44              │ 10:45              │
# ├───────────────────────┼──────────────────┼──────────────────┼────────────┼────────┼────────────────────┼────────────────────┤
# │ Doncaster             │ 10:53            │ 10:52            │          1 │ -      │                    │                    │
# ╰───────────────────────┴──────────────────┴──────────────────┴────────────┴────────┴────────────────────┴────────────────────╯
